@@ -175,8 +175,33 @@ class Interval(Enum):
 
 
 class TdxMarket(Enum):
-    CFFEX = 47
-    CZCE = 28
-    DCE = 29
-    SHFE = 30
-    SGE = 46
+    """
+    from jotdx.exhq import TdxExHq_API
+    api = TdxExHq_API()
+    # 59.175.238.38 : 7727
+    with api.connect('59.175.238.38', 7727):
+        df1 = api.to_df(api.get_markets())
+    """
+    CFFEX = 47      # 中金所期货
+    CZCE = 28       # 郑州商品
+    DCE = 29        # 大连商品
+    SHFE = 30       # 上海期货
+    SGE = 46        # 上海黄金
+    HKSE = 31       # 香港股票
+
+
+class TdxCategory(Enum):
+    """
+    from jotdx.exhq import TdxExHq_API
+    api = TdxExHq_API()
+    # 59.175.238.38 : 7727
+    with api.connect('59.175.238.38', 7727):
+        df1 = api.to_df(api.get_markets())
+        df3 = api.to_df(api.get_instrument_quote_list(30, 3, count=100))
+    """
+    CFFEX = 3     # 中金所期货
+    CZCE = 3      # 郑州商品
+    DCE = 3       # 大连商品
+    SHFE = 3      # 上海期货
+    SGE = 11      # 上海黄金
+    HKSE = 2      # 香港股票
